==> deepin-font-manager_6.0.3.tar.xz: BUILD/translations/deepin-font-manager_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>bütün şriftlər</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>İstifadəçi</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Seçilmişlər</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Çincə</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Bərabər genişlikli</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 bir şrift ailəsidir, əgər davam etsəniz ondakı bütün şriftlər silinəcəkdir</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 şrift ailəsidir, əgər davam etsəniz ondakı bütün şriftlər aktiv ediləcəkdir</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 şrift ailəsidir, əgər davam etsəniz, ondakı bütün şriftlər söndürüləcəkdir</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktiv etmək</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Söndürmək</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Bütün seçilmiş şrift ailəsini tətbiq edin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Pozulmuş fayl</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Eyni versiya quraşdırılıb</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistem şrifti</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 şrift quraşdırıldı</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 şrift quraşdırıldı</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 şrifti quraşdırıla bilmədi. Diskdə kifayət qədər boş yer qalmayıb.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 şrifti quraşdırmaq mümkün olmadı. Diskdə kifayət qədər boş yer qalmayıb.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Bu şrift tətbiqlər üçün əlçatan deyil</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Bu şriftlər tətbiqlər üçün əlçatan deyil</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Digər %1 sistem sistem şriftləri silinə bilməz</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>İstifadə olunan &quot;%1&quot; şrifti silinə bilmədi</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Digər %1 sistem şrifti və &quot;%2&quot; istifadə olunan şrifti silinə bilmədi</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 şrift(lər)i silmək istədiyinizə əminsiniz</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Şriftlər silinir, lütfən gözləyin...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Şriftin doğrulanması</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Qurulacaq şriftlər yoxdur</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Davam etmək</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Əsas məlumat</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Üslub</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Növü</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiya</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Təsviri</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Tam adı</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-adı</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Ticarət markası</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Şrift İdarəetməsi</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Şrift idarəetməsi, istifadəçilərə şriftləri quraşdırmağa və idarə etməyə kömək edir.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Şriftlər yüklənir, lütfən gözləyin...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Şrift iş masanıza ixrac olundu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 şrift iş masanıza ixrac olundu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 şrift ixrac edilə bilmədi. Diskdə kifayət qədər yer yoxdur.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 şriftlərinin ixrac edilməsi alınmadı. Diskdə kifayət qədər yer yoxdur.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Şrift əlavə etmək</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktiv etmək</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Seçilmiş</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Seçilmişlərdən silmək</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Təfərrüatlar</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl menecerində göstərmək</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>İxrac</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>söndürülüb</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Şriftlər söndürüldü</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 istifadə olunur, onusöndürə bilməzsiniz </translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Sistem şriftlərini və istifadə olunan şriftləri söndürə bilməzsiniz</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sistem şriftlərini söndürə bilməzsiniz</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Şrifti quraşdırmaq</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Doğrulanır...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Pozulmuş fayl</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Quraşdırıldı</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Quraşdırılmayıb</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Şrifti quraşdırmaq</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticəsi yoxdur</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Şriftlər yoxdur</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Qısayolları göstərmək</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Yuxarı səhifələmək</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Aşağıya səhifələmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Şrift əlavə etmək</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Seçilmiş</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Seçilmişlərdən silmək</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Şrit haqqında məlumat</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Öncədən baxış mətnini daxil edin</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_az.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>bütün şriftlər</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>İstifadəçi</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Seçilmişlər</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Çincə</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Bərabər genişlikli</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 bir şrift ailəsidir, əgər davam etsəniz ondakı bütün şriftlər silinəcəkdir</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 şrift ailəsidir, əgər davam etsəniz ondakı bütün şriftlər aktiv ediləcəkdir</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 şrift ailəsidir, əgər davam etsəniz, ondakı bütün şriftlər söndürüləcəkdir</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Aktiv etmək</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Söndürmək</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Bütün seçilmiş şrift ailəsini tətbiq edin</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Pozulmuş fayl</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Eyni versiya quraşdırılıb</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Sistem şrifti</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 şrift quraşdırıldı</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 şrift quraşdırıldı</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 şrifti quraşdırıla bilmədi. Diskdə kifayət qədər boş yer qalmayıb.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 şrifti quraşdırmaq mümkün olmadı. Diskdə kifayət qədər boş yer qalmayıb.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">Pozulmuş fayl</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Bu şrift tətbiqlər üçün əlçatan deyil</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Bu şriftlər tətbiqlər üçün əlçatan deyil</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Digər %1 sistem sistem şriftləri silinə bilməz</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>İstifadə olunan &quot;%1&quot; şrifti silinə bilmədi</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Digər %1 sistem şrifti və &quot;%2&quot; istifadə olunan şrifti silinə bilmədi</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 şrift(lər)i silmək istədiyinizə əminsiniz</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Şriftlər silinir, lütfən gözləyin...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Şriftin doğrulanması</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Qurulacaq şriftlər yoxdur</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Çıxış</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Davam etmək</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Əsas məlumat</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Üslub</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Növü</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiya</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Təsviri</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Tam adı</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps-adı</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Ticarət markası</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Şrift İdarəetməsi</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Şrift idarəetməsi, istifadəçilərə şriftləri quraşdırmağa və idarə etməyə kömək edir.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Şriftlər yüklənir, lütfən gözləyin...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Şrift iş masanıza ixrac olundu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 şrift iş masanıza ixrac olundu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 şrift ixrac edilə bilmədi. Diskdə kifayət qədər yer yoxdur.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 şriftlərinin ixrac edilməsi alınmadı. Diskdə kifayət qədər yer yoxdur.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Şrift əlavə etmək</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Aktiv etmək</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Seçilmiş</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Seçilmişlərdən silmək</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Təfərrüatlar</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl menecerində göstərmək</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>İxrac</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>söndürülüb</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Şriftlər söndürüldü</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 istifadə olunur, onusöndürə bilməzsiniz </translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Sistem şriftlərini və istifadə olunan şriftləri söndürə bilməzsiniz</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Sistem şriftlərini söndürə bilməzsiniz</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Şrifti quraşdırmaq</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Doğrulanır...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Pozulmuş fayl</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Quraşdırıldı</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Quraşdırılmayıb</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Şrifti quraşdırmaq</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticəsi yoxdur</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Şriftlər yoxdur</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Qısayolları göstərmək</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Yuxarı səhifələmək</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Aşağıya səhifələmək</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Şrift əlavə etmək</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Seçilmiş</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Seçilmişlərdən silmək</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Şrit haqqında məlumat</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Öncədən baxış mətnini daxil edin</translation>
    </message>
</context>
</TS>
